@@ -430,27 +430,46 @@ class Database(object):
 		if not response.success: return response
 		path = gfp.clean(f"{self.path}/{path}", remove_last_slash=True, remove_double_slash=True)
 		if not os.path.exists(str(path)):
-			return r3sponse.error(f"Specified path [{path}] does not exist.")
-		try:
-			format, _ = unpack(Files.load(path))
-		except Exception as e: return r3sponse.error(f"Failed to load content {path}, {e}.")
-		if format in ["list", "Array"]:
-			return r3sponse.success(f"Successfully parsed {path}.", {
-				"format":"Array",
-				"content":self.Array(path=path, default=default, aes=self.aes),
-			})
-		elif format in ["dict", "Dictionary"]:
-			return r3sponse.success(f"Successfully parsed {path}.", {
-				"format":"Dictionary",
-				"content":self.Dictionary(path=path, default=default, aes=self.aes),
-			})
-		elif format in ["file", "File"]:
-			return r3sponse.success(f"Successfully parsed {path}.", {
-				"format":"File",
-				"content":self.File(path=path, default=default, aes=self.aes),
-			})
+			if default == None:
+				return r3sponse.error(f"Specified path [{path}] does not exist.")
+			elif isinstance(default, (str, String, File)):
+				if isinstance(default, File):
+					default = default.data
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"File",
+					"content":self.File(path=path, default=str(default), aes=self.aes),
+				})
+			elif isinstance(default, (list, Array)):
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"Array",
+					"content":self.Array(path=path, default=default, aes=self.aes),
+				})
+			elif isinstance(default, (dict, Dictionary)):
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"Dictionary",
+					"content":self.Dictionary(path=path, default=default, aes=self.aes),
+				})
 		else:
-			return r3sponse.error(f"Unknown format [{format}] for path [{path}].")
+			try:
+				format, _ = unpack(Files.load(path))
+			except Exception as e: return r3sponse.error(f"Failed to load content {path}, {e}.")
+			if format in ["list", "Array"]:
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"Array",
+					"content":self.Array(path=path, default=default, aes=self.aes),
+				})
+			elif format in ["dict", "Dictionary"]:
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"Dictionary",
+					"content":self.Dictionary(path=path, default=default, aes=self.aes),
+				})
+			elif format in ["file", "File"]:
+				return r3sponse.success(f"Successfully parsed {path}.", {
+					"format":"File",
+					"content":self.File(path=path, default=default, aes=self.aes),
+				})
+			else:
+				return r3sponse.error(f"Unknown format [{format}] for path [{path}].")
 	def save(self, 
 		# the content object (! param number 1).
 		content=None,
@@ -476,7 +495,9 @@ class Database(object):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
+			self.loaded = False
 			File.__init__(self, path=self.path)
+			if default != None: self.check(default=default, save=True)
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
@@ -512,7 +533,9 @@ class Database(object):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
+			self.loaded = False
 			Array.__init__(self, path=self.path)
+			if default != None: self.check(default=default, save=True)
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
@@ -553,7 +576,9 @@ class Database(object):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.base = FilePath(self.path).base()
 			self.aes = aes
+			self.loaded = False
 			Dictionary.__init__(self, path=self.path)
+			if default != None: self.check(default=default, save=True)
 		def load(self):
 			try:
 				format, content = unpack(Files.load(self.path))
